/**
  ******************************************************************************
  * @file    main.c
  * @author  MCD Application Team
  * @version V4.1.0
  * @date    26-May-2017
  * @brief   Joystick Mouse demo main file
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2017 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */


/* Includes ------------------------------------------------------------------*/
#include "hw_config.h"
/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
__IO uint8_t PrevXferComplete = 1;
RCC_ClocksTypeDef RCC_ClockFreq;

uint16_t KeyCurrent,KeyOld,KeyNoChangedTime;
uint16_t KeyPress;
uint16_t KeyDown,KeyUp,KeyLast;
uint16_t power_off_cnt = 0;

/* Extern variables ----------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/
void DelayXms(unsigned int x)               
{
 unsigned int i,j;
 for(i=0;i<x;i++)
 for(j=0;j<5150;j++);
}

void KeyScan(void)
{
	KeyCurrent=Get_Keys();    

	if(KeyCurrent!=KeyOld)
	{
		 KeyNoChangedTime=0;
		 KeyOld=KeyCurrent; 
		 return;
	}
	else
  {
   KeyNoChangedTime++;
   if(KeyNoChangedTime>=1) 
   {
			KeyNoChangedTime=1;
			KeyPress=KeyOld; 
			KeyDown|=(~KeyLast)&(KeyPress);
			KeyUp|=KeyLast&(~KeyPress); 
			KeyLast=KeyPress; 
   }
  }
}

void Power_On()
{
	GPIO_SetBits(GPIOA, GPIO_Pin_8);
	GPIO_SetBits(GPIOB, GPIO_Pin_2);
	DelayXms(500);
	
	GPIO_ResetBits(GPIOB, GPIO_Pin_2);
	DelayXms(5);
	
	GPIO_SetBits(GPIOA, GPIO_Pin_6);
	DelayXms(20);
	
	GPIO_SetBits(GPIOA, GPIO_Pin_7);
}

void Power_Off()
{
	GPIO_ResetBits(GPIOA, GPIO_Pin_7);
	DelayXms(20);
	
	GPIO_ResetBits(GPIOA, GPIO_Pin_6);
	DelayXms(20);
	
	GPIO_SetBits(GPIOB, GPIO_Pin_2);
	DelayXms(500);
	GPIO_ResetBits(GPIOB, GPIO_Pin_2);
	DelayXms(1000);
	GPIO_SetBits(GPIOB, GPIO_Pin_2);
	DelayXms(500);
	GPIO_ResetBits(GPIOB, GPIO_Pin_2);
	DelayXms(20);
	
	GPIO_ResetBits(GPIOA, GPIO_Pin_8);
}


/*******************************************************************************
* Function Name  : main.
* Description    : main routine.
* Input          : None.
* Output         : None.
* Return         : None.
*******************************************************************************/
int main(void)
{
  Set_System();
	
	GPIO_ResetBits(GPIOB, GPIO_Pin_2);  //KEY_IP
	GPIO_ResetBits(GPIOA, GPIO_Pin_6);  //RASP_EN
	GPIO_ResetBits(GPIOA, GPIO_Pin_7);  //PWM_LCD
	GPIO_ResetBits(GPIOA, GPIO_Pin_8);  //PWR_CTL
	
	DelayXms(2000);
	Power_On();
	
	while(GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_9) == 0x00)
	{;}
  
  USB_Interrupts_Config();
  
  Set_USBClock();
  
  USB_Init();
  
  while (1)
  {
		DelayXms(5);
    KeyScan();
    if (KeyUp||KeyDown)
    {
      Joystick_Send(KeyPress);
      KeyUp=0;
      KeyDown=0;
    }
		if(GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_9) == 0x00)
		{
			power_off_cnt++;
			if(power_off_cnt > 250)
				Power_Off();
		}
		else
			power_off_cnt = 0;
  }
}

#ifdef  USE_FULL_ASSERT
/*******************************************************************************
* Function Name  : assert_failed
* Description    : Reports the name of the source file and the source line number
*                  where the assert_param error has occurred.
* Input          : - file: pointer to the source file name
*                  - line: assert_param error line source number
* Output         : None
* Return         : None
*******************************************************************************/
void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  /* Infinite loop */
  while (1)
  {}
}
#endif

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
